/**
 * Weather Source Forecast API
 * Daily and hourly forecast data for latitude/longitude points, ZIP/Postal Codes, Designated Market Areas, and OnPoint™ points. Hourly forecast is up to 10 days out from current day. Daily forecast is up to 15 days out from current day. The Weather Source Forecast API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  An API key is required to authorize requests. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 *//* tslint:disable:no-unused-variable member-ordering */

import { Inject, Injectable, Optional }                      from '@angular/core';
import { HttpClient, HttpHeaders, HttpParams,
         HttpResponse, HttpEvent }                           from '@angular/common/http';
import { CustomHttpUrlEncodingCodec }                        from '../encoder';

import { Observable }                                        from 'rxjs';

import { ErrorObj } from '../model/errorObj';
import { ForecastDmaDayObj } from '../model/forecastDmaDayObj';
import { ForecastDmaHourObj } from '../model/forecastDmaHourObj';

import { BASE_PATH, COLLECTION_FORMATS }                     from '../variables';
import { Configuration }                                     from '../configuration';


@Injectable()
export class DmasService {

    protected basePath = 'https://forecast.weathersourceapis.com/v2';
    public defaultHeaders = new HttpHeaders();
    public configuration = new Configuration();

    constructor(protected httpClient: HttpClient, @Optional()@Inject(BASE_PATH) basePath: string, @Optional() configuration: Configuration) {
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }

    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes: string[]): boolean {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }


    /**
     * A day of forecast data for a DMA.
     * Returns a single day of forecast data for a Designated Market Area. The provided date must exist within the current valid 15-day forecast range.
     * @param dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param date An date formatted as a RFC3339 date value.
     * @param fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, precipProb, snowfall, snowfallProb)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param unitScale The unit scale for returned values.&lt;br&gt;
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public dmasDmaIdDaysDateGet(dmaId: number, date: string, fields: Array<string>, unitScale?: string, observe?: 'body', reportProgress?: boolean): Observable<ForecastDmaDayObj>;
    public dmasDmaIdDaysDateGet(dmaId: number, date: string, fields: Array<string>, unitScale?: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ForecastDmaDayObj>>;
    public dmasDmaIdDaysDateGet(dmaId: number, date: string, fields: Array<string>, unitScale?: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ForecastDmaDayObj>>;
    public dmasDmaIdDaysDateGet(dmaId: number, date: string, fields: Array<string>, unitScale?: string, observe: any = 'body', reportProgress: boolean = false ): Observable<any> {

        if (dmaId === null || dmaId === undefined) {
            throw new Error('Required parameter dmaId was null or undefined when calling dmasDmaIdDaysDateGet.');
        }

        if (date === null || date === undefined) {
            throw new Error('Required parameter date was null or undefined when calling dmasDmaIdDaysDateGet.');
        }

        if (fields === null || fields === undefined) {
            throw new Error('Required parameter fields was null or undefined when calling dmasDmaIdDaysDateGet.');
        }


        let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
        if (fields) {
            queryParameters = queryParameters.set('fields', fields.join(COLLECTION_FORMATS['csv']));
        }
        if (unitScale !== undefined && unitScale !== null) {
            queryParameters = queryParameters.set('unitScale', <any>unitScale);
        }

        let headers = this.defaultHeaders;

        // authentication (ApiKeyAuth) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["X-API-KEY"]) {
            headers = headers.set('X-API-KEY', this.configuration.apiKeys["X-API-KEY"]);
        }

        // to determine the Accept header
        let httpHeaderAccepts: string[] = [
            'application/json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.request<ForecastDmaDayObj>('get',`${this.basePath}/dmas/${encodeURIComponent(String(dmaId))}/days/${encodeURIComponent(String(date))}`,
            {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            }
        );
    }

    /**
     * A contiguous range of daily forecast data for a DMA.
     * Returns a contiguous range of daily forecast data for a Designated Market Area. The provided dates must exist within the current valid 15-day forecast range.
     * @param dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
     * @param dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
     * @param fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, precipProb, snowfall, snowfallProb)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param unitScale The unit scale for returned values.&lt;br&gt;
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public dmasDmaIdDaysDateStartdateEndGet(dmaId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, observe?: 'body', reportProgress?: boolean): Observable<ForecastDmaDayObj>;
    public dmasDmaIdDaysDateStartdateEndGet(dmaId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ForecastDmaDayObj>>;
    public dmasDmaIdDaysDateStartdateEndGet(dmaId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ForecastDmaDayObj>>;
    public dmasDmaIdDaysDateStartdateEndGet(dmaId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, observe: any = 'body', reportProgress: boolean = false ): Observable<any> {

        if (dmaId === null || dmaId === undefined) {
            throw new Error('Required parameter dmaId was null or undefined when calling dmasDmaIdDaysDateStartdateEndGet.');
        }

        if (dateStart === null || dateStart === undefined) {
            throw new Error('Required parameter dateStart was null or undefined when calling dmasDmaIdDaysDateStartdateEndGet.');
        }

        if (dateEnd === null || dateEnd === undefined) {
            throw new Error('Required parameter dateEnd was null or undefined when calling dmasDmaIdDaysDateStartdateEndGet.');
        }

        if (fields === null || fields === undefined) {
            throw new Error('Required parameter fields was null or undefined when calling dmasDmaIdDaysDateStartdateEndGet.');
        }


        let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
        if (fields) {
            queryParameters = queryParameters.set('fields', fields.join(COLLECTION_FORMATS['csv']));
        }
        if (unitScale !== undefined && unitScale !== null) {
            queryParameters = queryParameters.set('unitScale', <any>unitScale);
        }

        let headers = this.defaultHeaders;

        // authentication (ApiKeyAuth) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["X-API-KEY"]) {
            headers = headers.set('X-API-KEY', this.configuration.apiKeys["X-API-KEY"]);
        }

        // to determine the Accept header
        let httpHeaderAccepts: string[] = [
            'application/json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.request<ForecastDmaDayObj>('get',`${this.basePath}/dmas/${encodeURIComponent(String(dmaId))}/days/${encodeURIComponent(String(dateStart))},${encodeURIComponent(String(dateEnd))}`,
            {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            }
        );
    }

    /**
     * The complete daily forecast for a DMA.
     * Returns the complete set of forecast data for a Designated Market Area.&lt;br&gt;&lt;br&gt;**Alternatively using a query that specificies just the days required for your purposes will improve the query response time.**
     * @param dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, precipProb, snowfall, snowfallProb)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param unitScale The unit scale for returned values.&lt;br&gt;
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public dmasDmaIdDaysGet(dmaId: number, fields: Array<string>, unitScale?: string, observe?: 'body', reportProgress?: boolean): Observable<ForecastDmaDayObj>;
    public dmasDmaIdDaysGet(dmaId: number, fields: Array<string>, unitScale?: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ForecastDmaDayObj>>;
    public dmasDmaIdDaysGet(dmaId: number, fields: Array<string>, unitScale?: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ForecastDmaDayObj>>;
    public dmasDmaIdDaysGet(dmaId: number, fields: Array<string>, unitScale?: string, observe: any = 'body', reportProgress: boolean = false ): Observable<any> {

        if (dmaId === null || dmaId === undefined) {
            throw new Error('Required parameter dmaId was null or undefined when calling dmasDmaIdDaysGet.');
        }

        if (fields === null || fields === undefined) {
            throw new Error('Required parameter fields was null or undefined when calling dmasDmaIdDaysGet.');
        }


        let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
        if (fields) {
            queryParameters = queryParameters.set('fields', fields.join(COLLECTION_FORMATS['csv']));
        }
        if (unitScale !== undefined && unitScale !== null) {
            queryParameters = queryParameters.set('unitScale', <any>unitScale);
        }

        let headers = this.defaultHeaders;

        // authentication (ApiKeyAuth) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["X-API-KEY"]) {
            headers = headers.set('X-API-KEY', this.configuration.apiKeys["X-API-KEY"]);
        }

        // to determine the Accept header
        let httpHeaderAccepts: string[] = [
            'application/json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.request<ForecastDmaDayObj>('get',`${this.basePath}/dmas/${encodeURIComponent(String(dmaId))}/days`,
            {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            }
        );
    }

    /**
     * The complete hourly forecast for a DMA
     * Returns the complete set of forecast data for a Designated Market Area.&lt;br&gt;&lt;br&gt;**Alternatively using a query that specificies just the hours required for your purposes will improve the query response time.**
     * @param dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, precipProb, snowfall, snowfallProb)* * allPres *(mslPres, sfcPres)* * allRad *(radSolar)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param unitScale The unit scale for returned values.&lt;br&gt;
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public dmasDmaIdHoursGet(dmaId: number, fields: Array<string>, unitScale?: string, observe?: 'body', reportProgress?: boolean): Observable<ForecastDmaHourObj>;
    public dmasDmaIdHoursGet(dmaId: number, fields: Array<string>, unitScale?: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ForecastDmaHourObj>>;
    public dmasDmaIdHoursGet(dmaId: number, fields: Array<string>, unitScale?: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ForecastDmaHourObj>>;
    public dmasDmaIdHoursGet(dmaId: number, fields: Array<string>, unitScale?: string, observe: any = 'body', reportProgress: boolean = false ): Observable<any> {

        if (dmaId === null || dmaId === undefined) {
            throw new Error('Required parameter dmaId was null or undefined when calling dmasDmaIdHoursGet.');
        }

        if (fields === null || fields === undefined) {
            throw new Error('Required parameter fields was null or undefined when calling dmasDmaIdHoursGet.');
        }


        let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
        if (fields) {
            queryParameters = queryParameters.set('fields', fields.join(COLLECTION_FORMATS['csv']));
        }
        if (unitScale !== undefined && unitScale !== null) {
            queryParameters = queryParameters.set('unitScale', <any>unitScale);
        }

        let headers = this.defaultHeaders;

        // authentication (ApiKeyAuth) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["X-API-KEY"]) {
            headers = headers.set('X-API-KEY', this.configuration.apiKeys["X-API-KEY"]);
        }

        // to determine the Accept header
        let httpHeaderAccepts: string[] = [
            'application/json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.request<ForecastDmaHourObj>('get',`${this.basePath}/dmas/${encodeURIComponent(String(dmaId))}/hours`,
            {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            }
        );
    }

    /**
     * An hour of forecast data for a DMA
     * Returns a single hour of forecast data for a Designated Market Area. The provided timestamp must exist within the current valid 10-day forecast range.
     * @param dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, precipProb, snowfall, snowfallProb)* * allPres *(mslPres, sfcPres)* * allRad *(radSolar)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param unitScale The unit scale for returned values.&lt;br&gt;
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public dmasDmaIdHoursTimestampGet(dmaId: number, timestamp: Date, fields: Array<string>, unitScale?: string, observe?: 'body', reportProgress?: boolean): Observable<ForecastDmaHourObj>;
    public dmasDmaIdHoursTimestampGet(dmaId: number, timestamp: Date, fields: Array<string>, unitScale?: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ForecastDmaHourObj>>;
    public dmasDmaIdHoursTimestampGet(dmaId: number, timestamp: Date, fields: Array<string>, unitScale?: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ForecastDmaHourObj>>;
    public dmasDmaIdHoursTimestampGet(dmaId: number, timestamp: Date, fields: Array<string>, unitScale?: string, observe: any = 'body', reportProgress: boolean = false ): Observable<any> {

        if (dmaId === null || dmaId === undefined) {
            throw new Error('Required parameter dmaId was null or undefined when calling dmasDmaIdHoursTimestampGet.');
        }

        if (timestamp === null || timestamp === undefined) {
            throw new Error('Required parameter timestamp was null or undefined when calling dmasDmaIdHoursTimestampGet.');
        }

        if (fields === null || fields === undefined) {
            throw new Error('Required parameter fields was null or undefined when calling dmasDmaIdHoursTimestampGet.');
        }


        let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
        if (fields) {
            queryParameters = queryParameters.set('fields', fields.join(COLLECTION_FORMATS['csv']));
        }
        if (unitScale !== undefined && unitScale !== null) {
            queryParameters = queryParameters.set('unitScale', <any>unitScale);
        }

        let headers = this.defaultHeaders;

        // authentication (ApiKeyAuth) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["X-API-KEY"]) {
            headers = headers.set('X-API-KEY', this.configuration.apiKeys["X-API-KEY"]);
        }

        // to determine the Accept header
        let httpHeaderAccepts: string[] = [
            'application/json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.request<ForecastDmaHourObj>('get',`${this.basePath}/dmas/${encodeURIComponent(String(dmaId))}/hours/${encodeURIComponent(String(timestamp))}`,
            {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            }
        );
    }

    /**
     * A contiguous range of hourly forecast data for a DMA.
     * Returns a contiguous range of hourly forecast data for a Designated Market Area. The provided timestamps must exist within the current valid 10-day forecast range.
     * @param dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
     * @param timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, precipProb, snowfall, snowfallProb)* * allPres *(mslPres, sfcPres)* * allRad *(radSolar)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param unitScale The unit scale for returned values.&lt;br&gt;
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, observe?: 'body', reportProgress?: boolean): Observable<ForecastDmaHourObj>;
    public dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ForecastDmaHourObj>>;
    public dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ForecastDmaHourObj>>;
    public dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, observe: any = 'body', reportProgress: boolean = false ): Observable<any> {

        if (dmaId === null || dmaId === undefined) {
            throw new Error('Required parameter dmaId was null or undefined when calling dmasDmaIdHoursTimestampStarttimestampEndGet.');
        }

        if (timestampStart === null || timestampStart === undefined) {
            throw new Error('Required parameter timestampStart was null or undefined when calling dmasDmaIdHoursTimestampStarttimestampEndGet.');
        }

        if (timestampEnd === null || timestampEnd === undefined) {
            throw new Error('Required parameter timestampEnd was null or undefined when calling dmasDmaIdHoursTimestampStarttimestampEndGet.');
        }

        if (fields === null || fields === undefined) {
            throw new Error('Required parameter fields was null or undefined when calling dmasDmaIdHoursTimestampStarttimestampEndGet.');
        }


        let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
        if (fields) {
            queryParameters = queryParameters.set('fields', fields.join(COLLECTION_FORMATS['csv']));
        }
        if (unitScale !== undefined && unitScale !== null) {
            queryParameters = queryParameters.set('unitScale', <any>unitScale);
        }

        let headers = this.defaultHeaders;

        // authentication (ApiKeyAuth) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["X-API-KEY"]) {
            headers = headers.set('X-API-KEY', this.configuration.apiKeys["X-API-KEY"]);
        }

        // to determine the Accept header
        let httpHeaderAccepts: string[] = [
            'application/json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.request<ForecastDmaHourObj>('get',`${this.basePath}/dmas/${encodeURIComponent(String(dmaId))}/hours/${encodeURIComponent(String(timestampStart))},${encodeURIComponent(String(timestampEnd))}`,
            {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            }
        );
    }

}
