/**
 * Weather Source Forecast API
 * Daily and hourly forecast data for latitude/longitude points, ZIP/Postal Codes, Designated Market Areas, and OnPoint™ points. Hourly forecast is up to 10 days out from current day. Daily forecast is up to 15 days out from current day. The Weather Source Forecast API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  An API key is required to authorize requests. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 *//* tslint:disable:no-unused-variable member-ordering */

import { Inject, Injectable, Optional }                      from '@angular/core';
import { HttpClient, HttpHeaders, HttpParams,
         HttpResponse, HttpEvent }                           from '@angular/common/http';
import { CustomHttpUrlEncodingCodec }                        from '../encoder';

import { Observable }                                        from 'rxjs';

import { ErrorObj } from '../model/errorObj';
import { ForecastPointDayObj } from '../model/forecastPointDayObj';
import { ForecastPointHourObj } from '../model/forecastPointHourObj';

import { BASE_PATH, COLLECTION_FORMATS }                     from '../variables';
import { Configuration }                                     from '../configuration';


@Injectable()
export class PointsService {

    protected basePath = 'https://forecast.weathersourceapis.com/v2';
    public defaultHeaders = new HttpHeaders();
    public configuration = new Configuration();

    constructor(protected httpClient: HttpClient, @Optional()@Inject(BASE_PATH) basePath: string, @Optional() configuration: Configuration) {
        if (basePath) {
            this.basePath = basePath;
        }
        if (configuration) {
            this.configuration = configuration;
            this.basePath = basePath || configuration.basePath || this.basePath;
        }
    }

    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm(consumes: string[]): boolean {
        const form = 'multipart/form-data';
        for (const consume of consumes) {
            if (form === consume) {
                return true;
            }
        }
        return false;
    }


    /**
     * A day of forecast data for a Latitude/Longitude point.
     * Returns a single day of forecast data for a Latitude/Longitude point. The provided date must exist within the current valid 15-day forecast range.
     * @param latitude A latitude value between -90° and 90°.
     * @param longitude A longitude value between -180° (West) and 180° (East).
     * @param date An date formatted as a RFC3339 date value.
     * @param fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, precipProb, snowfall, snowfallProb)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param unitScale The unit scale for returned values.&lt;br&gt;
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public pointsLatitudelongitudeDaysDateGet(latitude: number, longitude: number, date: string, fields: Array<string>, unitScale?: string, observe?: 'body', reportProgress?: boolean): Observable<ForecastPointDayObj>;
    public pointsLatitudelongitudeDaysDateGet(latitude: number, longitude: number, date: string, fields: Array<string>, unitScale?: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ForecastPointDayObj>>;
    public pointsLatitudelongitudeDaysDateGet(latitude: number, longitude: number, date: string, fields: Array<string>, unitScale?: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ForecastPointDayObj>>;
    public pointsLatitudelongitudeDaysDateGet(latitude: number, longitude: number, date: string, fields: Array<string>, unitScale?: string, observe: any = 'body', reportProgress: boolean = false ): Observable<any> {

        if (latitude === null || latitude === undefined) {
            throw new Error('Required parameter latitude was null or undefined when calling pointsLatitudelongitudeDaysDateGet.');
        }

        if (longitude === null || longitude === undefined) {
            throw new Error('Required parameter longitude was null or undefined when calling pointsLatitudelongitudeDaysDateGet.');
        }

        if (date === null || date === undefined) {
            throw new Error('Required parameter date was null or undefined when calling pointsLatitudelongitudeDaysDateGet.');
        }

        if (fields === null || fields === undefined) {
            throw new Error('Required parameter fields was null or undefined when calling pointsLatitudelongitudeDaysDateGet.');
        }


        let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
        if (fields) {
            queryParameters = queryParameters.set('fields', fields.join(COLLECTION_FORMATS['csv']));
        }
        if (unitScale !== undefined && unitScale !== null) {
            queryParameters = queryParameters.set('unitScale', <any>unitScale);
        }

        let headers = this.defaultHeaders;

        // authentication (ApiKeyAuth) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["X-API-KEY"]) {
            headers = headers.set('X-API-KEY', this.configuration.apiKeys["X-API-KEY"]);
        }

        // to determine the Accept header
        let httpHeaderAccepts: string[] = [
            'application/json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.request<ForecastPointDayObj>('get',`${this.basePath}/points/${encodeURIComponent(String(latitude))},${encodeURIComponent(String(longitude))}/days/${encodeURIComponent(String(date))}`,
            {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            }
        );
    }

    /**
     * A contiguous range of daily forecast data for a Latitude/Longitude point.
     * Returns a contiguous range of daily forecast data for a Latitude/Longitude point. The provided dates must exist within the current valid 15-day forecast range.
     * @param latitude A latitude value between -90° and 90°.
     * @param longitude A longitude value between -180° (West) and 180° (East).
     * @param dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
     * @param dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
     * @param fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, precipProb, snowfall, snowfallProb)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param unitScale The unit scale for returned values.&lt;br&gt;
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: number, longitude: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, observe?: 'body', reportProgress?: boolean): Observable<ForecastPointDayObj>;
    public pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: number, longitude: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ForecastPointDayObj>>;
    public pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: number, longitude: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ForecastPointDayObj>>;
    public pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: number, longitude: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, observe: any = 'body', reportProgress: boolean = false ): Observable<any> {

        if (latitude === null || latitude === undefined) {
            throw new Error('Required parameter latitude was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
        }

        if (longitude === null || longitude === undefined) {
            throw new Error('Required parameter longitude was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
        }

        if (dateStart === null || dateStart === undefined) {
            throw new Error('Required parameter dateStart was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
        }

        if (dateEnd === null || dateEnd === undefined) {
            throw new Error('Required parameter dateEnd was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
        }

        if (fields === null || fields === undefined) {
            throw new Error('Required parameter fields was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
        }


        let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
        if (fields) {
            queryParameters = queryParameters.set('fields', fields.join(COLLECTION_FORMATS['csv']));
        }
        if (unitScale !== undefined && unitScale !== null) {
            queryParameters = queryParameters.set('unitScale', <any>unitScale);
        }

        let headers = this.defaultHeaders;

        // authentication (ApiKeyAuth) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["X-API-KEY"]) {
            headers = headers.set('X-API-KEY', this.configuration.apiKeys["X-API-KEY"]);
        }

        // to determine the Accept header
        let httpHeaderAccepts: string[] = [
            'application/json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.request<ForecastPointDayObj>('get',`${this.basePath}/points/${encodeURIComponent(String(latitude))},${encodeURIComponent(String(longitude))}/days/${encodeURIComponent(String(dateStart))},${encodeURIComponent(String(dateEnd))}`,
            {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            }
        );
    }

    /**
     * The complete daily forecast for a Latitude/Longitude point.
     * Returns the complete set of forecast data for a Latitude/Longitude point.&lt;br&gt;&lt;br&gt;**Alternatively using a query that specificies just the days required for your purposes will improve the query response time.**
     * @param latitude A latitude value between -90° and 90°.
     * @param longitude A longitude value between -180° (West) and 180° (East).
     * @param fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, precipProb, snowfall, snowfallProb)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param unitScale The unit scale for returned values.&lt;br&gt;
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public pointsLatitudelongitudeDaysGet(latitude: number, longitude: number, fields: Array<string>, unitScale?: string, observe?: 'body', reportProgress?: boolean): Observable<ForecastPointDayObj>;
    public pointsLatitudelongitudeDaysGet(latitude: number, longitude: number, fields: Array<string>, unitScale?: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ForecastPointDayObj>>;
    public pointsLatitudelongitudeDaysGet(latitude: number, longitude: number, fields: Array<string>, unitScale?: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ForecastPointDayObj>>;
    public pointsLatitudelongitudeDaysGet(latitude: number, longitude: number, fields: Array<string>, unitScale?: string, observe: any = 'body', reportProgress: boolean = false ): Observable<any> {

        if (latitude === null || latitude === undefined) {
            throw new Error('Required parameter latitude was null or undefined when calling pointsLatitudelongitudeDaysGet.');
        }

        if (longitude === null || longitude === undefined) {
            throw new Error('Required parameter longitude was null or undefined when calling pointsLatitudelongitudeDaysGet.');
        }

        if (fields === null || fields === undefined) {
            throw new Error('Required parameter fields was null or undefined when calling pointsLatitudelongitudeDaysGet.');
        }


        let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
        if (fields) {
            queryParameters = queryParameters.set('fields', fields.join(COLLECTION_FORMATS['csv']));
        }
        if (unitScale !== undefined && unitScale !== null) {
            queryParameters = queryParameters.set('unitScale', <any>unitScale);
        }

        let headers = this.defaultHeaders;

        // authentication (ApiKeyAuth) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["X-API-KEY"]) {
            headers = headers.set('X-API-KEY', this.configuration.apiKeys["X-API-KEY"]);
        }

        // to determine the Accept header
        let httpHeaderAccepts: string[] = [
            'application/json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.request<ForecastPointDayObj>('get',`${this.basePath}/points/${encodeURIComponent(String(latitude))},${encodeURIComponent(String(longitude))}/days`,
            {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            }
        );
    }

    /**
     * The complete hourly forecast for a Latitude/Longitude point.
     * Returns the complete set of forecast data for a Latitude/Longitude point.&lt;br&gt;&lt;br&gt;**Alternatively using a query that specificies just the hours required for your purposes will improve the query response time.**
     * @param latitude A latitude value between -90° and 90°.
     * @param longitude A longitude value between -180° (West) and 180° (East).
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, precipProb, snowfall, snowfallProb)* * allPres *(mslPres, sfcPres)* * allRad *(radSolar)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param unitScale The unit scale for returned values.&lt;br&gt;
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public pointsLatitudelongitudeHoursGet(latitude: number, longitude: number, fields: Array<string>, unitScale?: string, observe?: 'body', reportProgress?: boolean): Observable<ForecastPointHourObj>;
    public pointsLatitudelongitudeHoursGet(latitude: number, longitude: number, fields: Array<string>, unitScale?: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ForecastPointHourObj>>;
    public pointsLatitudelongitudeHoursGet(latitude: number, longitude: number, fields: Array<string>, unitScale?: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ForecastPointHourObj>>;
    public pointsLatitudelongitudeHoursGet(latitude: number, longitude: number, fields: Array<string>, unitScale?: string, observe: any = 'body', reportProgress: boolean = false ): Observable<any> {

        if (latitude === null || latitude === undefined) {
            throw new Error('Required parameter latitude was null or undefined when calling pointsLatitudelongitudeHoursGet.');
        }

        if (longitude === null || longitude === undefined) {
            throw new Error('Required parameter longitude was null or undefined when calling pointsLatitudelongitudeHoursGet.');
        }

        if (fields === null || fields === undefined) {
            throw new Error('Required parameter fields was null or undefined when calling pointsLatitudelongitudeHoursGet.');
        }


        let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
        if (fields) {
            queryParameters = queryParameters.set('fields', fields.join(COLLECTION_FORMATS['csv']));
        }
        if (unitScale !== undefined && unitScale !== null) {
            queryParameters = queryParameters.set('unitScale', <any>unitScale);
        }

        let headers = this.defaultHeaders;

        // authentication (ApiKeyAuth) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["X-API-KEY"]) {
            headers = headers.set('X-API-KEY', this.configuration.apiKeys["X-API-KEY"]);
        }

        // to determine the Accept header
        let httpHeaderAccepts: string[] = [
            'application/json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.request<ForecastPointHourObj>('get',`${this.basePath}/points/${encodeURIComponent(String(latitude))},${encodeURIComponent(String(longitude))}/hours`,
            {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            }
        );
    }

    /**
     * An hour of forecast data for a Latitude/Longitude point.
     * Returns a single hour of forecast data for a Latitude/Longitude point. The provided timestamp must exist within the current valid 10-day forecast range.
     * @param latitude A latitude value between -90° and 90°.
     * @param longitude A longitude value between -180° (West) and 180° (East).
     * @param timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, precipProb, snowfall, snowfallProb)* * allPres *(mslPres, sfcPres)* * allRad *(radSolar)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param unitScale The unit scale for returned values.&lt;br&gt;
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public pointsLatitudelongitudeHoursTimestampGet(latitude: number, longitude: number, timestamp: Date, fields: Array<string>, unitScale?: string, observe?: 'body', reportProgress?: boolean): Observable<ForecastPointHourObj>;
    public pointsLatitudelongitudeHoursTimestampGet(latitude: number, longitude: number, timestamp: Date, fields: Array<string>, unitScale?: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ForecastPointHourObj>>;
    public pointsLatitudelongitudeHoursTimestampGet(latitude: number, longitude: number, timestamp: Date, fields: Array<string>, unitScale?: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ForecastPointHourObj>>;
    public pointsLatitudelongitudeHoursTimestampGet(latitude: number, longitude: number, timestamp: Date, fields: Array<string>, unitScale?: string, observe: any = 'body', reportProgress: boolean = false ): Observable<any> {

        if (latitude === null || latitude === undefined) {
            throw new Error('Required parameter latitude was null or undefined when calling pointsLatitudelongitudeHoursTimestampGet.');
        }

        if (longitude === null || longitude === undefined) {
            throw new Error('Required parameter longitude was null or undefined when calling pointsLatitudelongitudeHoursTimestampGet.');
        }

        if (timestamp === null || timestamp === undefined) {
            throw new Error('Required parameter timestamp was null or undefined when calling pointsLatitudelongitudeHoursTimestampGet.');
        }

        if (fields === null || fields === undefined) {
            throw new Error('Required parameter fields was null or undefined when calling pointsLatitudelongitudeHoursTimestampGet.');
        }


        let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
        if (fields) {
            queryParameters = queryParameters.set('fields', fields.join(COLLECTION_FORMATS['csv']));
        }
        if (unitScale !== undefined && unitScale !== null) {
            queryParameters = queryParameters.set('unitScale', <any>unitScale);
        }

        let headers = this.defaultHeaders;

        // authentication (ApiKeyAuth) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["X-API-KEY"]) {
            headers = headers.set('X-API-KEY', this.configuration.apiKeys["X-API-KEY"]);
        }

        // to determine the Accept header
        let httpHeaderAccepts: string[] = [
            'application/json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.request<ForecastPointHourObj>('get',`${this.basePath}/points/${encodeURIComponent(String(latitude))},${encodeURIComponent(String(longitude))}/hours/${encodeURIComponent(String(timestamp))}`,
            {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            }
        );
    }

    /**
     * A contiguous range of hourly forecast data for a Latitude/Longitude point.
     * Returns a contiguous range of hourly forecast data for a Latitude/Longitude point. The provided timestamps must exist within the current valid 10-day forecast range.
     * @param latitude A latitude value between -90° and 90°.
     * @param longitude A longitude value between -180° (West) and 180° (East).
     * @param timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
     * @param timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
     * @param fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, precipProb, snowfall, snowfallProb)* * allPres *(mslPres, sfcPres)* * allRad *(radSolar)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param unitScale The unit scale for returned values.&lt;br&gt;
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    public pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: number, longitude: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, observe?: 'body', reportProgress?: boolean): Observable<ForecastPointHourObj>;
    public pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: number, longitude: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<ForecastPointHourObj>>;
    public pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: number, longitude: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<ForecastPointHourObj>>;
    public pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: number, longitude: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, observe: any = 'body', reportProgress: boolean = false ): Observable<any> {

        if (latitude === null || latitude === undefined) {
            throw new Error('Required parameter latitude was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
        }

        if (longitude === null || longitude === undefined) {
            throw new Error('Required parameter longitude was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
        }

        if (timestampStart === null || timestampStart === undefined) {
            throw new Error('Required parameter timestampStart was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
        }

        if (timestampEnd === null || timestampEnd === undefined) {
            throw new Error('Required parameter timestampEnd was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
        }

        if (fields === null || fields === undefined) {
            throw new Error('Required parameter fields was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
        }


        let queryParameters = new HttpParams({encoder: new CustomHttpUrlEncodingCodec()});
        if (fields) {
            queryParameters = queryParameters.set('fields', fields.join(COLLECTION_FORMATS['csv']));
        }
        if (unitScale !== undefined && unitScale !== null) {
            queryParameters = queryParameters.set('unitScale', <any>unitScale);
        }

        let headers = this.defaultHeaders;

        // authentication (ApiKeyAuth) required
        if (this.configuration.apiKeys && this.configuration.apiKeys["X-API-KEY"]) {
            headers = headers.set('X-API-KEY', this.configuration.apiKeys["X-API-KEY"]);
        }

        // to determine the Accept header
        let httpHeaderAccepts: string[] = [
            'application/json'
        ];
        const httpHeaderAcceptSelected: string | undefined = this.configuration.selectHeaderAccept(httpHeaderAccepts);
        if (httpHeaderAcceptSelected != undefined) {
            headers = headers.set('Accept', httpHeaderAcceptSelected);
        }

        // to determine the Content-Type header
        const consumes: string[] = [
        ];

        return this.httpClient.request<ForecastPointHourObj>('get',`${this.basePath}/points/${encodeURIComponent(String(latitude))},${encodeURIComponent(String(longitude))}/hours/${encodeURIComponent(String(timestampStart))},${encodeURIComponent(String(timestampEnd))}`,
            {
                params: queryParameters,
                withCredentials: this.configuration.withCredentials,
                headers: headers,
                observe: observe,
                reportProgress: reportProgress
            }
        );
    }

}
